# melpoi
melpoi is a repository with some of the scripts me myself personally find useful. They can be a simple ETL script or even a web scraping script. This is mainly for me to have a centralized place to look for scripts that I need. Feel free to use them if they can help you, you can also submit a pull request to add new things into this that you feel others might benefit from it.

# Categories
- [Scraping](https://github.com/la0bing/melpoi/tree/main/melpoi/scraping)
- [SQL](https://github.com/la0bing/melpoi/tree/main/melpoi/sql)
